// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package jobqueue

import (
	"github.com/robfig/cron/v3"
	"go.uber.org/zap"
	"strings"
	"time"
)

// ExampleManager shows how to use the manager
func ExampleManager() {

	testData := []byte(`
- id: job1
  priority: 1
  timeout: 1s
  maxRetries: 3
  retryDelay: 1s
  runnable:
   type: shell
   data:
     script: echo "~1~ $(date "+%M:%S")" >> /tmp/job1.log
  scheduler:
   type: cron
   spec: "*/10 * * * * *"
`)

	var err error

	cronInstance := cron.New(cron.WithSeconds())
	cronInstance.Start()

	zapLogger, _ := zap.NewDevelopment()
	_ = zapLogger

	manager := NewManager()
	manager.SetLogger(&ZapAdapter{logger: zapLogger})

	manager.SetCronInstance(cronInstance)
	worker := NewLocalWorker(10)
	worker.SetManager(manager)
	err = manager.AddWorker(worker)

	err = manager.Start()
	if err != nil {
		panic(err)
	}

	reader := strings.NewReader(string(testData))

	err = ImportJobsAndSchedule(reader, "yaml", manager)
	if err != nil {
		panic(err)
	}

	time.Sleep(30 * time.Second)

}
