{
  pkgs,
  lib,
  ...
}: let
  common = pkgs.callPackage ./common.nix {};
in
  pkgs.writeShellScriptBin "check-code" ''

    ${common}

    echo_header "Checking code"
    cd_working_dir

    echo_step "Formatting Nix code"
    if ! ${pkgs.alejandra}/bin/alejandra flake.nix ./nix/scripts/*.nix
    then
      echo_fail "alejandra formatting failed"
      exit 1
    fi

    ##format go code
    echo_step "Formatting Go code"
    if ! ${pkgs.go}/bin/gofmt -s -w .
    then
      echo_fail "gofmt failed"
      exit 1
    fi

    echo_step "Add license headers"
    if ! ${pkgs.addlicense}/bin/addlicense -c "schukai GmbH" -s -l "AGPL-3.0" ./*.go
    then
      echo_fail "addlicense failed"
      exit 1
    fi

    echo_step "Running go-licenses"
    readonly defaultPacke=$(awk -F ' ' '/^module / { print $2 }' ./go.mod)
    ${pkgs.go-licenses}/bin/go-licenses save "$defaultPacke" --ignore "gitlab.schukai.com" --force --save_path ./licenses/

    echo_step "Running go vet"
    if ! ${pkgs.go}/bin/go vet .
    then
      echo_fail "go vet failed"
      exit 1
    fi

    echo_step "Running go fmt"
    if ! ${pkgs.go}/bin/go fmt .
    then
      echo_fail "go fmt failed"
      exit 1
    fi

    echo_step "Running go mod tidy"
    if ! ${pkgs.go}/bin/go mod tidy
    then
      echo_fail "go mod tidy failed"
      exit 1
    fi

    echo_step "Running lint"
    if ! ${pkgs.golangci-lint}/bin/golangci-lint run .
    then
      echo_fail "lint failed"
      exit 1
    fi

    echo_step "Running gosec"
    if ! ${pkgs.gosec}/bin/gosec -quiet .
    then
      echo_fail "gosec failed"
      exit 1
    fi


  ''
